should_verify_loaded_value

Function should_verify_loaded_value 

pub(crate) fn should_verify_loaded_value(
    tcx: TyCtxt<'_>,
    prev_fingerprint: Fingerprint,
) -> bool
Whether a value loaded from the on-disk cache should have its fingerprint verified with incremental_verify_ich. If -Zincremental-verify-ich is specified, re-hash results from the cache and make sure that they have the expected fingerprint.

If not, we still seek to verify a subset of fingerprints loaded from disk. Re-hashing results is fairly expensive, so we can’t currently afford to verify every hash. This subset should still give us some coverage of potential bugs.